@@ -1,4 +1,4 @@
-#' @title Add or get DublinCore metadata
+#' @title Add or get Dublin Core metadata
 #' @description Add metadata conforming the
 #' \href{https://www.dublincore.org/specifications/dublin-core/dcmi-terms/terms/format/}{DCMI Metadata Terms}.
 #' to datasets, i.e. structured R data.frame or list objects, for an accurate and consistent identification
@@ -13,9 +13,10 @@
 #' structured R list.
 #' @details The \code{ResourceType} property will be by definition "Dataset".
 #' The \code{Size} attribute (e.g. bytes, pages, inches, etc.) will automatically added to the dataset.
-#' @param title \href{https://purl.org/dc/elements/1.1/title}{dct:title}, a name given to the resource.
+#' @param title \href{https://www.dublincore.org/specifications/dublin-core/dcmi-terms/elements11/title/}{dct:title}, a name given to the resource.
 #' \code{\link{datacite}} allows the use of alternate titles, too. See \code{\link{dataset_title}}.
-#' @param creator An entity primarily responsible for making the resource. \href{https://purl.org/dc/elements/1.1/creator}{dct:creator}
+#' @param creator An entity primarily responsible for making the resource.
+#' \href{https://www.dublincore.org/specifications/dublin-core/dcmi-terms/elements11/creator/}{dct:creator}
 #' Corresponds to \code{Creator} in \code{\link{datacite}}. See \code{\link{creator}}.
 #' @param identifier An unambiguous reference to the resource within a given context.
 #' Recommended practice is to identify the resource by means of a string conforming to an
@@ -34,31 +35,32 @@
 #' "holds, archives, publishes, prints, distributes, releases, issues, or produces" the
 #' code, use the property Contributor/contributorType/hostingInstitution for the code
 #' repository. See \code{\link{publisher}}.
-#' @param subject In \href{https://purl.org/dc/elements/1.1/subject}{dct:subject}. In
+#' @param subject In \href{https://www.dublincore.org/specifications/dublin-core/dcmi-terms/elements11/subject/}{dct:subject}. In
 #' \code{\link{datacite}} it is a recommended property for discovery. In DataCite, a more complex
 #' referencing is used. See \code{\link{subject}} and create structured Subject objects with
 #' \code{\link{subject_create}}.
 #' @param date Corresponds to a point or period of time associated with an event in the
-#' lifecycle of the resource. \href{https://purl.org/dc/elements/1.1/date}{dct:date}.
+#' lifecycle of the resource. \href{https://www.dublincore.org/specifications/dublin-core/dcmi-terms/elements11/date/}{dct:date}.
 #' \code{Date} is also recommended for
 #' discovery in \code{\link{datacite}}, but it requires a different formatting.
 #' @param language The primary language of the resource. Allowed values are taken from
 #' IETF BCP 47, ISO 639-1 language code. See \code{\link{language}}. Corresponds to Language in Datacite.
 #' @param format The file format, physical medium, or dimensions of the resource.
-#' \href{	https://purl.org/dc/elements/1.1/format}{dct:format}
+#' \href{https://www.dublincore.org/specifications/dublin-core/dcmi-terms/elements11/format/}{dct:format}
 #' Examples of dimensions include size and duration. Recommended best practice is to use a controlled
 #' vocabulary such as the list of \href{https://www.iana.org/assignments/media-types/media-types.xhtml}{Internet Media Types, formerly known as MIME}. It is similar to \code{Format} in
 #' \code{\link{datacite}}.
-#' @param rights Corresponds to \href{https://purl.org/dc/elements/1.1/rights}{dct:rights} and
+#' @param rights Corresponds to \href{https://www.dublincore.org/specifications/dublin-core/dcmi-terms/elements11/rights/}{dct:rights} and
 #' \code{\link{datacite}} Rights. Information about rights held in and over the resource.
 #' Typically, rights information includes a statement about various property rights associated with the resource,
 #' including intellectual property rights. See \code{\link{rights}}.
 #' @param description An account of the resource. It may include but is not limited to:
 #' an abstract, a table of contents, a graphical representation, or a free-text account of the resource.
-#' \href{https://purl.org/dc/elements/1.1/description}{dct:description}. In
+#' \href{https://www.dublincore.org/specifications/dublin-core/dcmi-terms/elements11/description/}{dct:description}. In
 #' \code{\link{datacite}} it is recommended for discovery. See \code{\link{description}}.
 #' @param relation A related resource. Recommended best practice is to identify the related
-#' resource by means of a string conforming to a formal identification system. See: \href{https://purl.org/dc/elements/1.1/relation}{dct:relation}.
+#' resource by means of a string conforming to a formal identification system.
+#' See: \href{https://www.dublincore.org/specifications/dublin-core/dcmi-terms/elements11/relation/}{dct:relation}.
 #' Similar to \code{RelatedItem} in \code{\link{datacite}}, which is recommended for discovery.
 #' @param type The nature or genre of the resource. Recommended best practice is to use a controlled vocabulary such as the DCMI Type Vocabulary
 #' \href{https://www.dublincore.org/specifications/dublin-core/dcmi-type-vocabulary/}{DCMITYPE}.
@@ -160,12 +162,12 @@ as_dublincore <- function(x, type = "bibentry", ...) {
     if ( is_person(arguments$author))  {
       citation_author <- arguments$author
     } else {
-      stop("as_datacite(x, ..., author = ): author must be created with utils::person().")
+      stop("as_dublincore(x, ..., author = ): author must be created with utils::person().")
     }
   }
 
   if (! type %in% c("bibentry", "list", "dataset")) {
-    warning_message <- "as_datacite(ds, type=...) type cannot be "
+    warning_message <- "as_dublincore(ds, type=...) type cannot be "
     warning(warning_message, type, ". Reverting to 'bibentry'.")
     type <- 'bibentry'
   }
@@ -174,6 +176,9 @@ as_dublincore <- function(x, type = "bibentry", ...) {
   dataset_title   <- ds_bibentry$title
   dataset_creator <- ds_bibentry$author
 
+  if (! is_person(dataset_creator)) {
+    stop('attr(x, "DataBibentry")$author is not a person object.')
+  }
 
   if (!is.null(ds_bibentry$year)) {
     if(!is.null(ds_bibentry$year)) {
